# Tasmota Device Manager
Easy to use GUI application to manage, configure and monitor devices flashed with [Tasmota firmware](https://github.com/arendst/Tasmota)

[![GitHub release (latest SemVer)](https://img.shields.io/github/v/release/jziolkowski/tdm?style=for-the-badge)](https://github.com/jziolkowski/tdm/releases/latest)
[![GitHub All Releases](https://img.shields.io/github/downloads/jziolkowski/tdm/total?logo=github&style=for-the-badge)](https://github.com/jziolkowski/tdm/releases/latest)
[![https://pypi.org/project/tdmgr/](https://img.shields.io/pypi/dw/tdmgr?logo=pypi&style=for-the-badge)](https://pypi.org/project/tdmgr/)
[![Discord](https://img.shields.io/discord/545967340794413078?logo=discord&style=for-the-badge)](https://discord.gg/eAhVDXM)

![image](https://user-images.githubusercontent.com/11555742/66050573-bf764900-e52d-11e9-8356-e3dbf4ef6205.png)

#### Minimum fully-supported Tasmota firmware version: [6.6.0.17](https://github.com/arendst/Tasmota/blob/development/tasmota/CHANGELOG.md#66017-20191009)

# Features

 - [autodiscovery](https://github.com/jziolkowski/tdm/wiki/Autodiscovery) of Tasmota devices (even if they use custom FullTopics)
 - module, GPIO and template configuration
 - rules edito with Var/Mem/Ruletimer monitor
 - easy to read detachable telemetry viewers (working in active and passive mode) 
 - relay, color and PWM control
 - user-friendly configuration of buttons, switches and relays, including their related SetOptions
 - timers editor
 - clear retained relay and LWT topics
 - detachable device consoles with command completion and intuitive history 
 - selectable views to see the most vital device parameters at a glance
 - BSSID aliasing for larger deployments

# Planned functions
  
 - PWM/NTP/Topics configuration dialogs and a few others
 - config export for OpenHAB and HomeAssistant
 - dynamic and manual grouping of devices: by group topic, module, firmware revision, and more
 - group actions: reset/restart/control power/upgrade
 - quick settings for common use cases
 - code completion in rules editor
 - built-in OTA server
 - and much more! (you're welcome to post feature requests)

# Requirements and installation instructions

See the [wiki article](https://github.com/jziolkowski/tdm/wiki/Prerequisites-installation-and-running)

Uses free icons from [Icons8](https://icons8.com)

<a href="https://www.buymeacoffee.com/eYmkLXO" target="_blank"><img src="https://bmc-cdn.nyc3.digitaloceanspaces.com/BMC-button-images/custom_images/orange_img.png" alt="Buy Me A Coffee" style="height: auto !important;width: auto !important;" ></a>
